@@ -2,16 +2,15 @@ use simple_async_cache_rs::AsyncCacheStore;
 use std::time::Duration;
 use tokio::time::sleep;
 
-
 #[tokio::main]
 async fn main() {
     // Create an AsyncCacheStore using implicit typing with an expiration delay of 10 seconds.
-    let mut store = AsyncCacheStore::new(10);
+    let store = AsyncCacheStore::new();
 
     // If you want to explicitly define types you can do the following:
     // let mut store: Arc<AsyncCacheStore<String, String>> = AsyncCacheStore::new(60);
 
-    let cache = store.get("key_1".to_string()).await;
+    let cache = store.get("key_1".to_string(), 10).await;
     let mut result = cache.lock().await;
     match &mut *result {
         Some(_d) => {
@@ -26,15 +25,12 @@ async fn main() {
 
     // The value for key_1 is still cached.
     assert_eq!(
-        *store.get("key_1".to_string()).await.lock().await,
+        *store.get("key_1".to_string(), 0).await.lock().await,
         Some("This is the first value for key_1.")
     );
 
     // We sleep for 15 seconds, the value for key_1 is expired.
     sleep(Duration::from_secs(15)).await;
 
-    assert_eq!(
-        *store.get("key_1".to_string()).await.lock().await,
-        None
-    );
-}
\ No newline at end of file
+    assert_eq!(*store.get("key_1".to_string(), 0).await.lock().await, None);
+}
